@@ -10,9 +10,13 @@ private_lib_dir <- function() {
   mydir <- getNamespaceInfo(asNamespace(.packageName), "path")
   embedded <- file.path(mydir, "library")
 
-  if (file.exists(embedded)) return(c(embedded = embedded))
+  if (file.exists(embedded)) {
+    return(c(embedded = embedded))
+  }
   ppl <- Sys.getenv("PAK_PRIVATE_LIBRARY", NA_character_)
-  if (!is.na(ppl)) return(ppl)
+  if (!is.na(ppl)) {
+    return(ppl)
+  }
 
   file.path(
     user_cache_dir("pak"),
