@@ -17,7 +17,9 @@ remote <- function(func, args = list()) {
     timeout <- suppressWarnings(as.numeric(
       Sys.getenv("PKG_SUBPROCESS_TIMEOUT", "")
     ))
-    if (is.na(timeout)) timeout <- 5000
+    if (is.na(timeout)) {
+      timeout <- 5000
+    }
     pr <- pkg_data$ns$processx$poll(list(rs$get_poll_connection()), timeout)[[
       1
     ]]
@@ -27,7 +29,9 @@ remote <- function(func, args = list()) {
       state <- rs$get_state()
     }
   }
-  if (state != "idle") stop("Subprocess is busy or cannot start")
+  if (state != "idle") {
+    stop("Subprocess is busy or cannot start")
+  }
 
   func2 <- func
   width <- pkg_data$ns$cli$console_width()
@@ -79,7 +83,8 @@ remote <- function(func, args = list()) {
   }
   pkg_envs <- envs[grepl("^PKG_", names(envs)) | names(envs) %in% extraenvs]
   rs$run(
-    function(new_opts, new_envs) {
+    function(wd, new_opts, new_envs) {
+      setwd(wd)
       opts <- options()
       old_opts <- opts[grepl("^pkg[.]", names(opts))]
       # remove all pkg.* options
@@ -95,7 +100,7 @@ remote <- function(func, args = list()) {
       Sys.unsetenv(old_envs)
       if (length(new_envs)) do.call("Sys.setenv", as.list(new_envs))
     },
-    list(new_opts = pkg_options, new_envs = pkg_envs)
+    list(wd = getwd(), new_opts = pkg_options, new_envs = pkg_envs)
   )
 
   res <- withCallingHandlers(
@@ -103,8 +108,11 @@ remote <- function(func, args = list()) {
       withRestarts(
         {
           signalCondition(msg)
-          out <- if (is_interactive() || sink.number() > 0) stdout() else
+          out <- if (is_interactive() || sink.number() > 0) {
+            stdout()
+          } else {
             stderr()
+          }
           cat(conditionMessage(msg), file = out, sep = "")
         },
         muffleMessage = function() NULL
@@ -250,8 +258,9 @@ load_private_package <- function(
     tryCatch(
       {
         pkg_dir <- pkg_env[["__pkg-dir__"]]
-        if (!is.null(pkg_dir))
+        if (!is.null(pkg_dir)) {
           pkg_dir <- suppressWarnings(normalizePath(pkg_dir))
+        }
         if (!is.null(pkg_env[[".onUnload"]])) {
           tryCatch(pkg_env[[".onUnload"]](pkg_dir), error = function(e) e)
         }
@@ -260,7 +269,9 @@ load_private_package <- function(
         matchidx <- grepl(pkg_dir, paths, fixed = TRUE)
         if (any(matchidx)) {
           pkglibs <- libs[matchidx]
-          for (lib in pkglibs) dyn.unload(lib[["path"]])
+          for (lib in pkglibs) {
+            dyn.unload(lib[["path"]])
+          }
           .dynLibs(libs[!matchidx])
         }
         unlink(dirname(pkg_dir), recursive = TRUE, force = TRUE)
