@@ -1,6 +1,10 @@
-
-pkg_error <- function(..., .data = NULL, .class = NULL, .envir = parent.frame(),
-                      call. = TRUE) {
+pkg_error <- function(
+  ...,
+  .data = NULL,
+  .class = NULL,
+  .envir = parent.frame(),
+  call. = TRUE
+) {
   .hide_from_trace <- TRUE
   cnd <- new_error(
     call. = call.,
@@ -13,7 +17,32 @@ pkg_error <- function(..., .data = NULL, .class = NULL, .envir = parent.frame(),
   )
 
   if (length(.data)) cnd[names(.data)] <- .data
-  if (length(class)) class(cnd) <- c(.class, class(cnd))
+  if (length(.class)) class(cnd) <- c(.class, class(cnd))
+
+  cnd
+}
+
+pkg_warning <- function(
+  ...,
+  .data = NULL,
+  .class = NULL,
+  .envir = parent.frame(),
+  call. = TRUE
+) {
+  .hide_from_trace <- TRUE
+  cnd <- new_cond(
+    call. = call.,
+    cli::format_error(
+      .envir = .envir,
+      c(
+        ...
+      )
+    )
+  )
+  class(cnd) <- c(.class, "warning", "condition")
+
+  if (length(.data)) cnd[names(.data)] <- .data
+  if (length(.class)) class(cnd) <- c(.class, class(cnd))
 
   cnd
 }
